@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Help;
 
-our $DATE = '2017-07-22'; # DATE
-our $VERSION = '0.15'; # VERSION
+our $DATE = '2017-07-24'; # DATE
+our $VERSION = '0.16'; # VERSION
 
 use 5.010001;
 use strict;
@@ -70,17 +70,16 @@ sub gen_help {
 
     # summary
     my $progname = $args{program_name};
-    push @help, $progname;
     {
         my $sum = $args{program_summary} // $meta->{summary};
         last unless $sum;
-        push @help, " - ", $sum, "\n";
+        push @help, $progname, " - ", $sum, "\n\n";
     }
 
     my $clidocdata;
 
     # usage
-    push @help, "\nUsage:\n";
+    push @help, "Usage:\n";
     {
         for (sort {
             ($common_opts->{$a}{order} // 99) <=>
@@ -255,7 +254,7 @@ Perinci::CmdLine::Help - Generate help message for Perinci::CmdLine-based app
 
 =head1 VERSION
 
-This document describes version 0.15 of Perinci::CmdLine::Help (from Perl distribution Perinci-CmdLine-Help), released on 2017-07-22.
+This document describes version 0.16 of Perinci::CmdLine::Help (from Perl distribution Perinci-CmdLine-Help), released on 2017-07-24.
 
 =head1 DESCRIPTION
 
